@@ -25,14 +25,14 @@ struct ClientSpec {
     // errors on platforms with older gcc versions, e.g. OS X 10.6.
     inline ClientSpec(const QString &spriteKey = QString(),
                       int frame = -1,
-                      const QSize &size = QSize(),
+                      QSize size = QSize(),
                       const QHash<QColor, QColor> &customColors = (QHash<QColor, QColor>()));
     QString spriteKey;
     int frame;
     QSize size;
     QHash<QColor, QColor> customColors;
 };
-ClientSpec::ClientSpec(const QString &spriteKey_, int frame_, const QSize &size_, const QHash<QColor, QColor> &customColors_)
+ClientSpec::ClientSpec(const QString &spriteKey_, int frame_, QSize size_, const QHash<QColor, QColor> &customColors_)
     : spriteKey(spriteKey_)
     , frame(frame_)
     , size(size_)
@@ -102,9 +102,10 @@ class KGameRendererPrivate : public QObject
     Q_OBJECT
 
 public:
-    KGameRendererPrivate(KgThemeProvider *provider, unsigned cacheSize, KGameRenderer *parent);
-    void _k_setTheme(const KgTheme *theme);
-    bool setTheme(const KgTheme *theme);
+    KGameRendererPrivate(KGameThemeProvider *provider, unsigned cacheSize, KGameRenderer *parent);
+
+    void _k_setTheme(const KGameTheme *theme);
+    bool setTheme(const KGameTheme *theme);
     inline QString spriteFrameKey(const QString &key, int frame, bool normalizeFrameNo = false) const;
     void requestPixmap(const KGRInternal::ClientSpec &spec, KGameRendererClient *client, QPixmap *synchronousResult = nullptr);
 
@@ -112,24 +113,26 @@ private:
     inline void requestPixmap__propagateResult(const QPixmap &pixmap, KGameRendererClient *client, QPixmap *synchronousResult);
 public Q_SLOTS:
     void jobFinished(KGRInternal::Job *job, bool isSynchronous); // NOTE: This is invoked from KGRInternal::Worker::run.
-public:
-    KGameRenderer *m_parent;
 
-    KgThemeProvider *m_provider;
-    const KgTheme *m_currentTheme;
+public:
+    KGameRenderer *const m_parent;
+
+    KGameThemeProvider *m_provider;
+    const KGameTheme *m_currentTheme = nullptr; // will be loaded on first use
+
     QString m_frameSuffix, m_sizePrefix, m_frameCountPrefix, m_boundsPrefix;
     unsigned m_cacheSize;
-    KGameRenderer::Strategies m_strategies;
-    int m_frameBaseIndex;
-    QGraphicsView *m_defaultPrimaryView;
+    KGameRenderer::Strategies m_strategies = KGameRenderer::UseDiskCache | KGameRenderer::UseRenderingThreads;
+    int m_frameBaseIndex = 0;
 
     QThreadPool m_workerPool;
-    KGRInternal::RendererPool m_rendererPool;
+    mutable KGRInternal::RendererPool m_rendererPool;
 
     QHash<KGameRendererClient *, QString> m_clients; // maps client -> cache key of current pixmap
     QStringList m_pendingRequests; // cache keys of pixmaps which are currently being rendered
 
-    KImageCache *m_imageCache;
+    KImageCache *m_imageCache = nullptr;
+
     // In multi-threaded scenarios, there are two possible ways to use KIC's
     // pixmap cache.
     // 1. The worker renders a QImage and stores it in the cache. The main
@@ -151,8 +154,8 @@ public:
     // As you see, implementing an own pixmap cache saves us one conversion.
     // We therefore disable KIC's pixmap cache because we do not need it.
     QHash<QString, QPixmap> m_pixmapCache;
-    QHash<QString, int> m_frameCountCache;
-    QHash<QString, QRectF> m_boundsCache;
+    mutable QHash<QString, int> m_frameCountCache;
+    mutable QHash<QString, QRectF> m_boundsCache;
 };
 
 class KGameRendererClientPrivate : public QObject
@@ -166,7 +169,8 @@ public Q_SLOTS:
     void fetchPixmap();
 
 public:
-    KGameRendererClient *m_parent;
+    KGameRendererClient *const m_parent;
+
     KGameRenderer *m_renderer;
 
     KGRInternal::ClientSpec m_spec;
